@@ -1,13 +1,15 @@
 """
 rapid string matching library
 """
+from __future__ import annotations
+
 __author__: str = "Max Bachmann"
 __license__: str = "MIT"
-__version__: str = "2.13.5"
+__version__: str = "3.1.2"
 
-from rapidfuzz import distance, fuzz, process, string_metric, utils
+from rapidfuzz import distance, fuzz, process, utils
 
-__all__ = ["distance", "fuzz", "process", "string_metric", "utils", "get_include"]
+__all__ = ["distance", "fuzz", "process", "utils", "get_include"]
 
 
 def get_include():
@@ -25,6 +27,6 @@ def get_include():
                 include_dirs=[rapidfuzz_capi.get_include()])
         ...
     """
-    import os
+    from pathlib import Path
 
-    return os.path.dirname(__file__)
+    return str(Path(__file__).parent)
